==> localstack-ext-0.13.0.4.tar.gz: localstack-ext-0.13.0.4/localstack_ext/bootstrap/cpvcs/utils/remote_utils.py <==
import logging
LCSse=str
LCSsM=False
LCSsy=open
LCSsP=Exception
LCSsk=None
LCSsf=isinstance
LCSsX=dict
LCSsc=list
LCSsN=len
import os
import shutil
import zipfile
from typing import Dict
from localstack.utils.common import merge_recursive,new_tmp_dir,rm_rf
from localstack_ext.bootstrap.cpvcs.constants import COMPRESSION_FORMAT
from localstack_ext.bootstrap.cpvcs.obj_storage import default_storage as object_storage
from localstack_ext.bootstrap.cpvcs.utils.common import CPVCSConfigContext,config_context
from localstack_ext.bootstrap.state_utils import(check_already_visited,get_object_dict,load_persisted_object)
LOG=logging.getLogger(__name__)
def extract_meta_and_state_archives(meta_archives:Dict[LCSse,LCSse],state_archives:Dict[LCSse,LCSse]):
 for product_space_archive in[meta_archives,state_archives]:
  for version_no,archive in product_space_archive.items():
   with zipfile.ZipFile(archive)as meta_zip:
    if product_space_archive==meta_archives:
     archive_dest=config_context.get_version_meta_archive_path(version_no=version_no,with_format=LCSsM)
    else:
     archive_dest=config_context.get_version_state_archive_path(version_no=version_no,with_format=LCSsM)
    meta_zip.extractall(archive_dest)
    shutil.make_archive(base_name=archive_dest,format=COMPRESSION_FORMAT,root_dir=archive_dest)
    rm_rf(archive_dest)
    rm_rf(archive)
    LOG.debug(f"Successfully extracted archive {product_space_archive} for version {version_no}")
def register_remote(remote_info:Dict[LCSse,LCSse]):
 if config_context.is_remotly_managed():
  LOG.warning("Pod is already remotely managed")
  return
 with LCSsy(config_context.get_remote_info_path(),"w")as fp:
  storage_uuid=remote_info.get("storage_uuid")
  qualifying_name=remote_info.get("qualifying_name")
  fp.write(f"storage_uuid={storage_uuid}\n")
  fp.write(f"qualifying_name={qualifying_name}\n")
def merge_version_space(version_space_archive):
 remote_version_space_dir=new_tmp_dir()
 remote_config_context=CPVCSConfigContext(pod_root_dir=remote_version_space_dir)
 with zipfile.ZipFile(version_space_archive)as version_space_zip:
  version_space_zip.extractall(remote_config_context.get_pod_root_dir())
 shutil.copy(remote_config_context.get_known_ver_path(),config_context.get_known_ver_path())
 shutil.copy(remote_config_context.get_max_ver_path(),config_context.get_max_ver_path())
 remote_rev_obj_store_path=remote_config_context.get_rev_obj_store_path()
 local_rev_obj_store_path=config_context.get_rev_obj_store_path()
 for revision_file in os.listdir(remote_rev_obj_store_path):
  remote_revision_file_path=os.path.join(remote_rev_obj_store_path,revision_file)
  local_revision_file_path=os.path.join(local_rev_obj_store_path,revision_file)
  shutil.copy(remote_revision_file_path,local_revision_file_path)
 for version_ref_file in os.listdir(remote_config_context.get_ver_refs_path()):
  remote_version_ref_file_path=remote_config_context.get_version_ref_file_path(version_ref_file)
  local_version_ref_file_path=config_context.get_version_ref_file_path(version_ref_file)
  with LCSsy(remote_version_ref_file_path,"r")as fp:
   key=fp.readline().strip()
  if os.path.isfile(local_version_ref_file_path):
   object_storage.merge_remote_into_local_version(remote_config_context.get_ver_obj_store_path(),key)
  else:
   remote_version_file_path=os.path.join(remote_config_context.get_ver_obj_store_path(),key)
   local_version_file_path=os.path.join(config_context.get_ver_obj_store_path(),key)
   shutil.copy(remote_version_ref_file_path,local_version_ref_file_path)
   shutil.copy(remote_version_file_path,local_version_file_path)
 rm_rf(remote_version_space_dir)
 rm_rf(version_space_archive)
def _metadata_create_func(**kwargs):
 try:
  dir_name=kwargs.get("dir_name")
  file_name=kwargs.get("fname")
  region=kwargs.get("region")
  service_name=kwargs.get("service_name")
  mutables=kwargs.get("mutables")
  metamodels=mutables[0]
  file_path=os.path.join(dir_name,file_name)
  backend_state=load_persisted_object(file_path)
  service_metamodel=_create_metamodel_helper(backend_state)or{}
  region_metamodels=metamodels[region]=metamodels.get(region)or{}
  region_service_models=region_metamodels[service_name]=(region_metamodels.get(service_name)or{})
  service_info=mutables[1]
  merge_recursive(service_metamodel,region_service_models)
  service_region_info=service_info.setdefault(region,{})
  service_info=service_region_info.setdefault(service_name,{})
  service_info["size"]=service_info.get("size",0)+os.path.getsize(file_path)
 except LCSsP as e:
  LOG.exception(f"Unable to create metamodel for state object {kwargs} : {e}")
def _create_metamodel_helper(obj,width=25,visited:set=LCSsk):
 if obj is LCSsk:
  return obj
 cycle,visited=check_already_visited(obj,visited)
 if cycle:
  return obj
 result=obj=get_object_dict(obj)or obj
 if LCSsf(obj,LCSsX):
  result=LCSsX(result)
  for field_name,field_value in result.items():
   result[field_name]=_create_metamodel_helper(field_value,width=width,visited=visited)
 elif LCSsf(obj,LCSsc):
  result=[_create_metamodel_helper(o,width=width,visited=visited)for o in obj]
  if LCSsN(result)>width:
   result={"size":LCSsN(result),"items":result[:width]}
 return result
# Created by pyminifier (https://github.com/liftoff/pyminifier)

==> localstack-ext-0.14.0.21.tar.gz: localstack-ext-0.14.0.21/localstack_ext/bootstrap/cpvcs/utils/remote_utils.py <==
import logging
import os
import shutil
import zipfile
from typing import Dict
from localstack.utils.common import new_tmp_dir,rm_rf
from localstack_ext.bootstrap.cpvcs.constants import COMPRESSION_FORMAT
from localstack_ext.bootstrap.cpvcs.obj_storage import default_storage as object_storage
from localstack_ext.bootstrap.cpvcs.utils.common import CPVCSConfigContext,config_context
LOG=logging.getLogger(__name__)
def extract_meta_and_state_archives(meta_archives:Dict[str,str],state_archives:Dict[str,str]):
 for product_space_archive in[meta_archives,state_archives]:
  for version_no,archive in product_space_archive.items():
   with zipfile.ZipFile(archive)as meta_zip:
    if product_space_archive==meta_archives:
     archive_dest=config_context.get_version_meta_archive_path(version=version_no,with_format=False)
    else:
     archive_dest=config_context.get_version_state_archive_path(version=version_no,with_format=False)
    meta_zip.extractall(archive_dest)
    shutil.make_archive(base_name=archive_dest,format=COMPRESSION_FORMAT,root_dir=archive_dest)
    rm_rf(archive_dest)
    rm_rf(archive)
    LOG.debug(f"Successfully extracted archive {product_space_archive} for version {version_no}")
def register_remote(remote_info:Dict[str,str]):
 if config_context.is_remotly_managed():
  LOG.warning("Pod is already remotely managed")
  return
 with open(config_context.get_remote_info_path(),"w")as fp:
  storage_uuid=remote_info.get("storage_uuid")
  qualifying_name=remote_info.get("qualifying_name")
  fp.write(f"storage_uuid={storage_uuid}\n")
  fp.write(f"qualifying_name={qualifying_name}\n")
def merge_version_space(version_space_archive):
 remote_version_space_dir=new_tmp_dir()
 remote_config_context=CPVCSConfigContext(pod_root_dir=remote_version_space_dir)
 with zipfile.ZipFile(version_space_archive)as version_space_zip:
  version_space_zip.extractall(remote_config_context.get_pod_root_dir())
 shutil.copy(remote_config_context.get_known_ver_path(),config_context.get_known_ver_path())
 shutil.copy(remote_config_context.get_max_ver_path(),config_context.get_max_ver_path())
 remote_rev_obj_store_path=remote_config_context.get_rev_obj_store_path()
 local_rev_obj_store_path=config_context.get_rev_obj_store_path()
 for revision_file in os.listdir(remote_rev_obj_store_path):
  remote_revision_file_path=os.path.join(remote_rev_obj_store_path,revision_file)
  local_revision_file_path=os.path.join(local_rev_obj_store_path,revision_file)
  shutil.copy(remote_revision_file_path,local_revision_file_path)
 for version_ref_file in os.listdir(remote_config_context.get_ver_refs_path()):
  remote_version_ref_file_path=remote_config_context.get_version_ref_file_path(version_ref_file)
  local_version_ref_file_path=config_context.get_version_ref_file_path(version_ref_file)
  with open(remote_version_ref_file_path,"r")as fp:
   key=fp.readline().strip()
  if os.path.isfile(local_version_ref_file_path):
   object_storage.merge_remote_into_local_version(remote_config_context.get_ver_obj_store_path(),key)
  else:
   remote_version_file_path=os.path.join(remote_config_context.get_ver_obj_store_path(),key)
   local_version_file_path=os.path.join(config_context.get_ver_obj_store_path(),key)
   shutil.copy(remote_version_ref_file_path,local_version_ref_file_path)
   shutil.copy(remote_version_file_path,local_version_file_path)
 rm_rf(remote_version_space_dir)
 rm_rf(version_space_archive)
# Created by pyminifier (https://github.com/liftoff/pyminifier)
